==> deepin-camera_1.0.0.15.orig.tar.xz: deepin-camera-1.0.0.15/src/translations/deepin-camera_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Видео запись в процессе. Закрыть окно?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Открыть папку</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ничего</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Открыть папку</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>У вас нет разрешения вносить изменения в этой папке.</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation>Неверная папка</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Открыть папку</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Основной</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Местоположение файла</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Снимать</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Режим серийной съемки</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Задержка автоспуска</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Вывод</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Формат вывода</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 шт</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 шт</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ничего</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Камера - это приложение для захвата изображения и записи видео, используя веб-камеру вашего компьютера.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Файл не сохранен</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Сохранить на:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Фото:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Видео:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Настройки разрешения</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Разрешение:</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Снять фото</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Видеозапись</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Остановить фотосъемку</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Ничего</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Веб камера не найдена</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Веб камера включена</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Остановить видеозапись</translation>
    </message>
</context>
</TS>

==> deepin-camera_1.1.2.orig.tar.xz: deepin-camera-1.1.2/src/translations/deepin-camera_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Видео запись в процессе. Закрыть окно?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Открыть папку</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ничего</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Открыть папку</translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>У вас нет разрешения вносить изменения в этой папке.</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Неверная папка</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Открыть папку</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Основной</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Местоположение файла</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Снимать</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Режим серийной съемки</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Задержка автоспуска</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Вывод</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Формат вывода</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 шт</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 шт</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ничего</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Камера - это приложение для захвата изображения и записи видео, используя веб-камеру вашего компьютера.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Файл не сохранен</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Сохранить на:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Фото:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Видео:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Настройки разрешения</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Разрешение:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Остановить видеозапись</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Остановить фотосъемку</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Снять фото</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Видеозапись</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Остановить фотосъемку</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Ничего</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Веб камера не найдена</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Веб камера включена</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Остановить видеозапись</translation>
    </message>
</context>
</TS>
